==> cdi-tck-3.0.0-RC1-dist.zip: org/jboss/cdi/tck/interceptors/InterceptorsSections.java <==
package org.jboss.cdi.tck.interceptors;
@javax.annotation.Generated(value="org.jboss.test.audit.generate.SectionsClassGenerator", date="2020-07-30T03:10:55+0000")
public final class InterceptorsSections {
private InterceptorsSections() {}
/**
 * 1 Overview
 */
public static final String OVERVIEW = "overview";
/**
 * 2 Interceptor Programming Contract
 */
public static final String INT_PROGRAMMING_CONTRACT = "int_programming_contract";
/**
 * 2.1 Terminology
 */
public static final String TERMINOLOGY = "terminology";
/**
 * 2.2 Definition of Interceptor Classes and Interceptor Methods
 */
public static final String DEF_OF_INTERCEPTOR_CLASSES_AND_INTERCEPTOR_METHODS = "def_of_interceptor_classes_and_interceptor_methods";
/**
 * 2.3 Interceptor Life Cycle
 */
public static final String INTERCEPTOR_LIFECYCLE = "interceptor_lifecycle";
/**
 * 2.3.1 Interceptor Environment
 */
public static final String INTERCEPTOR_ENVIRONMENT = "interceptor_environment";
/**
 * 2.4 InvocationContext
 */
public static final String INVOCATIONCONTEXT = "invocationcontext";
/**
 * 2.5 Exceptions
 */
public static final String EXCEPTIONS = "exceptions";
/**
 * 2.6 Business Method Interceptor Methods
 */
public static final String BUSINESS_METHOD_INTERCEPTOR_METHODS = "business_method_interceptor_methods";
/**
 * 2.7 Interceptor Methods for Lifecycle Event Callbacks
 */
public static final String INT_METHODS_FOR_LIFECYCLE_EVENT_CALLBACKS = "int_methods_for_lifecycle_event_callbacks";
/**
 * 2.7.1 Exceptions
 */
public static final String LIC_EXCEPTIONS = "lic_exceptions";
/**
 * 2.8 Timeout Method Interceptor Methods
 */
public static final String TIMEOUT_METHOD_INT_METHODS = "timeout_method_int_methods";
/**
 * 2.9 Constructor- and Method-level Interceptors
 */
public static final String CONSTRUCTOR_AND_METHOD_LEVEL_INT = "constructor_and_method_level_int";
/**
 * 2.10 Default Interceptors
 */
public static final String DEFAULT_INTERCEPTORS = "default_interceptors";
/**
 * 3 Associating Interceptors with Classes and Methods using Interceptor Bindings
 */
public static final String ASSOCIATING_INT_USING_INT_BINDINGS = "associating_int_using_int_bindings";
/**
 * 3.1 Interceptor Binding Types
 */
public static final String INT_BINDING_TYPES = "int_binding_types";
/**
 * 3.1.1 Interceptor binding types with additional interceptor bindings
 */
public static final String INT_BINDING_TYPES_WITH_ADDITIONAL_INT_BINDINGS = "int_binding_types_with_additional_int_bindings";
/**
 * 3.1.2 Other sources of interceptor bindings
 */
public static final String OTHER_SOURCES_OF_INT_BINDINGS = "other_sources_of_int_bindings";
/**
 * 3.2 Declaring Interceptor Bindings of an Interceptor
 */
public static final String DECLARING_INTERCEPTOR_BINDINGS_OF_AN_INTERCEPTOR = "declaring_interceptor_bindings_of_an_interceptor";
/**
 * 3.3 Binding an Interceptor to a Component
 */
public static final String BINDING_INT_TO_COMPONENT = "binding_int_to_component";
/**
 * 3.4 Interceptor Resolution
 */
public static final String INT_RESOLUTION = "int_resolution";
/**
 * 3.4.1 Interceptors with multiple bindings
 */
public static final String INT_WITH_MULTIPLE_BINDINGS = "int_with_multiple_bindings";
/**
 * 3.4.2 Interceptor binding types with members
 */
public static final String INT_BINDING_TYPES_WITH_MEMBERS = "int_binding_types_with_members";
/**
 * 4 Associating Interceptors with Classes and Methods using the Interceptors Annotation
 */
public static final String ASSOCIATING_INT_USING_INTERCEPTORS_ANNOTATION = "associating_int_using_interceptors_annotation";
/**
 * 5 Interceptor Ordering
 */
public static final String INT_ORDERING = "int_ordering";
/**
 * 5.1 Enabling Interceptors
 */
public static final String ENABLING_INTERCEPTORS = "enabling_interceptors";
/**
 * 5.2 Interceptor Ordering Rules
 */
public static final String INT_ORDERING_RULES = "int_ordering_rules";
/**
 * 5.2.1 Use of the Priority Annotation in Ordering Interceptors
 */
public static final String PRIORITY_ANNOTATION_IN_ORDERING_INT = "priority_annotation_in_ordering_int";
/**
 * 5.3 Excluding Interceptors
 */
public static final String EXCLUDING_INTERCEPTORS = "excluding_interceptors";
}

==> cdi-tck-4.0.0-RC1-dist.zip: org/jboss/cdi/tck/interceptors/InterceptorsSections.java <==
package org.jboss.cdi.tck.interceptors;
@jakarta.annotation.Generated(value="org.jboss.test.audit.generate.SectionsClassGenerator", date="2021-12-13T20:23:23+0000")
public final class InterceptorsSections {
private InterceptorsSections() {}
/**
 * 1 Overview
 */
public static final String OVERVIEW = "overview";
/**
 * 2 Interceptor Programming Contract
 */
public static final String INT_PROGRAMMING_CONTRACT = "int_programming_contract";
/**
 * 2.1 Terminology
 */
public static final String TERMINOLOGY = "terminology";
/**
 * 2.2 Definition of Interceptor Classes and Interceptor Methods
 */
public static final String DEF_OF_INTERCEPTOR_CLASSES_AND_INTERCEPTOR_METHODS = "def_of_interceptor_classes_and_interceptor_methods";
/**
 * 2.3 Interceptor Life Cycle
 */
public static final String INTERCEPTOR_LIFECYCLE = "interceptor_lifecycle";
/**
 * 2.3.1 Interceptor Environment
 */
public static final String INTERCEPTOR_ENVIRONMENT = "interceptor_environment";
/**
 * 2.4 InvocationContext
 */
public static final String INVOCATIONCONTEXT = "invocationcontext";
/**
 * 2.5 Exceptions
 */
public static final String EXCEPTIONS = "exceptions";
/**
 * 2.6 Business Method Interceptor Methods
 */
public static final String BUSINESS_METHOD_INTERCEPTOR_METHODS = "business_method_interceptor_methods";
/**
 * 2.7 Interceptor Methods for Lifecycle Event Callbacks
 */
public static final String INT_METHODS_FOR_LIFECYCLE_EVENT_CALLBACKS = "int_methods_for_lifecycle_event_callbacks";
/**
 * 2.7.1 Exceptions
 */
public static final String LIC_EXCEPTIONS = "lic_exceptions";
/**
 * 2.8 Timeout Method Interceptor Methods
 */
public static final String TIMEOUT_METHOD_INT_METHODS = "timeout_method_int_methods";
/**
 * 2.9 Constructor- and Method-level Interceptors
 */
public static final String CONSTRUCTOR_AND_METHOD_LEVEL_INT = "constructor_and_method_level_int";
/**
 * 2.10 Default Interceptors
 */
public static final String DEFAULT_INTERCEPTORS = "default_interceptors";
/**
 * 3 Associating Interceptors with Classes and Methods using Interceptor Bindings
 */
public static final String ASSOCIATING_INT_USING_INT_BINDINGS = "associating_int_using_int_bindings";
/**
 * 3.1 Interceptor Binding Types
 */
public static final String INT_BINDING_TYPES = "int_binding_types";
/**
 * 3.1.1 Interceptor binding types with additional interceptor bindings
 */
public static final String INT_BINDING_TYPES_WITH_ADDITIONAL_INT_BINDINGS = "int_binding_types_with_additional_int_bindings";
/**
 * 3.1.2 Other sources of interceptor bindings
 */
public static final String OTHER_SOURCES_OF_INT_BINDINGS = "other_sources_of_int_bindings";
/**
 * 3.2 Declaring Interceptor Bindings of an Interceptor
 */
public static final String DECLARING_INTERCEPTOR_BINDINGS_OF_AN_INTERCEPTOR = "declaring_interceptor_bindings_of_an_interceptor";
/**
 * 3.3 Binding an Interceptor to a Component
 */
public static final String BINDING_INT_TO_COMPONENT = "binding_int_to_component";
/**
 * 3.4 Interceptor Resolution
 */
public static final String INT_RESOLUTION = "int_resolution";
/**
 * 3.4.1 Interceptors with multiple bindings
 */
public static final String INT_WITH_MULTIPLE_BINDINGS = "int_with_multiple_bindings";
/**
 * 3.4.2 Interceptor binding types with members
 */
public static final String INT_BINDING_TYPES_WITH_MEMBERS = "int_binding_types_with_members";
/**
 * 4 Associating Interceptors with Classes and Methods using the Interceptors Annotation
 */
public static final String ASSOCIATING_INT_USING_INTERCEPTORS_ANNOTATION = "associating_int_using_interceptors_annotation";
/**
 * 5 Interceptor Ordering
 */
public static final String INT_ORDERING = "int_ordering";
/**
 * 5.1 Enabling Interceptors
 */
public static final String ENABLING_INTERCEPTORS = "enabling_interceptors";
/**
 * 5.2 Interceptor Ordering Rules
 */
public static final String INT_ORDERING_RULES = "int_ordering_rules";
/**
 * 5.2.1 Use of the Priority Annotation in Ordering Interceptors
 */
public static final String PRIORITY_ANNOTATION_IN_ORDERING_INT = "priority_annotation_in_ordering_int";
/**
 * 5.3 Excluding Interceptors
 */
public static final String EXCLUDING_INTERCEPTORS = "excluding_interceptors";
}
